#!/usr/bin/python
# -*- coding: utf-8 -*-
# bas_dmo3.py

import sys
from PyQt5 import QtCore, QtGui, QtWidgets
import ADwin
from Ui_dialog import Ui_Form

DEVICENUMBER = 0x1

BTL = "ADwin9.btl"
PROCESS = "Bas_dmo3.t91"

class Dialog(QtWidgets.QDialog):
    def __init__(self, parent=None):
        QtWidgets.QDialog.__init__(self, parent)
        self.ui = Ui_Form()
        self.ui.setupUi(self)

        self.t1 = QtCore.QTimer()
        self.t1.setInterval(100)

        self.ui.btnQuit.clicked.connect(self.quit)
        self.ui.btnStart.clicked.connect(self.start)
        self.t1.timeout.connect(self.timer)

        self.adw = ADwin.ADwin(DEVICENUMBER, 1)
        btl = self.adw.ADwindir + BTL
        if sys.platform == 'win32':
            process = self.adw.ADwindir + "ADbasic\\samples_ADwin\\" + PROCESS
        else:
            process = self.adw.ADwindir + "share/examples/samples_ADwin/" + PROCESS
        self.adw.Boot(btl)
        self.adw.Load_Process(process)
        self.data = None
        self.minValue = 0
        self.maxValue = 0

    def quit(self):
        self.adw.Stop_Process(1)
        self.close()

    def start(self):
        self.adw.Start_Process(1)
        self.t1.start()
        QtWidgets.QApplication.setOverrideCursor(QtCore.Qt.WaitCursor)

    def paintEvent(self, event):
        rect = self.ui.frame.geometry()
        x1 = rect.x()
        y1 = rect.y() + 2
        x2 = x1 + rect.width() - 3
        y2 = y1 + rect.height() - 5
        paint = QtGui.QPainter()
        paint.begin(self)
        paint.setPen(QtCore.Qt.darkBlue)

        if self.data != None:
            anz = len(self.data)
            if ((self.maxValue - self.minValue) != 0) and (anz > 1):
                lx1 = x1
                ly1 = y2 - (float(self.data[0] - self.minValue)) / (self.maxValue - self.minValue) * (y2 - y1)
                lx2 = x1 + (1.0 / (anz-1)) * (x2-x1)
                ly2 = y2 - (float(self.data[1] - self.minValue)) / (self.maxValue - self.minValue) * (y2 - y1)
                paint.drawLine(lx1, ly1, lx2, ly2)
                for i in range(1, anz):
                    lx1, ly1 = lx2, ly2
                    lx2 = x1 + (float(i) / (anz-1)) * (x2-x1)
                    ly2 = y2 - (float(self.data[i] - self.minValue)) / (self.maxValue - self.minValue) * (y2 - y1)
                    paint.drawLine(lx1, ly1, lx2, ly2)
        paint.end()

    def timer(self):
        if self.adw.Get_Par(10) == 1:
            QtWidgets.QApplication.restoreOverrideCursor()
            self.t1.stop()
            self.data = self.adw.GetData_Long(1, 1, 1000)
            self.minValue = min(self.data)
            self.maxValue = max(self.data)
            self.ui.leMin.setText(str(self.minValue))
            self.ui.leMax.setText(str(self.maxValue))
            self.repaint()


APP = QtWidgets.QApplication(sys.argv)
dialog = Dialog()
sys.exit(dialog.exec_())
